@@ -29,7 +29,7 @@ RSpec.configure do |c|
   c.threadsafe = false
 
   # TODO: Only really relevant when using the filesystem data source
-  c.before(:each, site: true) do
+  c.before(:each, :site) do
     FileUtils.mkdir_p('content')
     FileUtils.mkdir_p('layouts')
     FileUtils.mkdir_p('lib')
@@ -44,7 +44,7 @@ RSpec.configure do |c|
     format: '%c/%C |<%b>%i| %p%%',
   }
 
-  c.before(:each, fork: true) do
+  c.before(:each, :fork) do
     skip 'fork() is not supported on Windows' if Nanoc::Core.on_windows?
   end
 
@@ -66,7 +66,7 @@ RSpec.configure do |c|
     end
   end
 
-  c.around(:each, stdio: true) do |example|
+  c.around(:each, :stdio) do |example|
     orig_stdout = $stdout
     orig_stderr = $stderr
 
@@ -96,7 +96,6 @@ RSpec::Matchers.define :send_notification do |name, *expected_args|
     end
 
     actual.call
-    Nanoc::Core::NotificationCenter.sync
 
     @actual_notifications.any? { |c| c == expected_args }
   end
@@ -107,7 +106,7 @@ RSpec::Matchers.define :send_notification do |name, *expected_args|
 
   failure_message do |_actual|
     s = "expected that proc would send notification #{name.inspect} with args #{expected_args.inspect}"
-    if @actual_notifications.any?
+    unless @actual_notifications.empty?
       s << " (received #{@actual_notifications.size} times with other arguments: #{@actual_notifications.map(&:inspect).join(', ')})"
     end
     s
@@ -191,29 +190,6 @@ RSpec::Matchers.define :finish_in_under do |expected|
   end
 end
 
-RSpec::Matchers.define :yield_from_fiber do |expected|
-  supports_block_expectations
-
-  include RSpec::Matchers::Composable
-
-  match do |actual|
-    @res = Fiber.new { actual.call }.resume
-    values_match?(expected, @res)
-  end
-
-  description do
-    "yield #{expected.inspect} from fiber"
-  end
-
-  failure_message do |_actual|
-    "expected that proc would yield #{expected.inspect} from fiber, but was #{@res.inspect}"
-  end
-
-  failure_message_when_negated do |_actual|
-    "expected that proc would not yield #{expected.inspect} from fiber, but was #{@res.inspect}"
-  end
-end
-
 RSpec::Matchers.define :be_some_textual_content do |expected|
   include RSpec::Matchers::Composable
 
@@ -332,10 +308,10 @@ RSpec::Matchers.define :have_a_valid_manifest do
 
   failure_message do |_actual|
     reasons = []
-    if @missing_from_manifest.any?
+    unless @missing_from_manifest.empty?
       reasons << "file(s) missing from manifest (#{@missing_from_manifest.join(', ')})"
     end
-    if @extra_in_manifest.any?
+    unless @extra_in_manifest.empty?
       reasons << "file(s) extra in manifest (#{@extra_in_manifest.join(', ')})"
     end
 
@@ -349,24 +325,17 @@ RSpec::Matchers.define :create_dependency_on do |expected|
   include RSpec::Matchers::Composable
 
   match do |actual|
-    @to = expected
-    dependency_tracker = @to._context.dependency_tracker
+    to = expected
+    dependency_tracker = to._context.dependency_tracker
     dependency_store = dependency_tracker.dependency_store
 
-    from = Nanoc::Core::Item.new('x', {}, '/x.md')
+    a = dependency_store.objects_causing_outdatedness_of(dependency_tracker.root)
 
-    a = dependency_store.objects_causing_outdatedness_of(from)
+    actual.call
 
-    begin
-      dependency_tracker.enter(from)
-      actual.call
-    ensure
-      dependency_tracker.exit
-    end
+    b = dependency_store.objects_causing_outdatedness_of(dependency_tracker.root)
 
-    b = dependency_store.objects_causing_outdatedness_of(from)
-
-    (b - a).include?(@to)
+    (b - a).include?(to)
   end
 
   description do
@@ -394,12 +363,7 @@ RSpec::Matchers.define :create_dependency_from do |expected|
 
     a = dependency_store.objects_causing_outdatedness_of(@from)
 
-    begin
-      dependency_tracker.enter(@from._unwrap)
-      actual.call
-    ensure
-      dependency_tracker.exit
-    end
+    actual.call
 
     b = dependency_store.objects_causing_outdatedness_of(@from)
 
@@ -408,7 +372,7 @@ RSpec::Matchers.define :create_dependency_from do |expected|
     if @onto
       values_match?(@onto, @actual)
     else
-      @actual.any?
+      !@actual.empty?
     end
   end
 
@@ -421,7 +385,7 @@ RSpec::Matchers.define :create_dependency_from do |expected|
   end
 
   failure_message do |_actual|
-    "expected a dependency to be created from #{expected.inspect}#{@onto ? " onto #{@onto.inspect}" : nil}, but generated #{@actual.inspect}"
+    "expected a dependency to be created from #{expected.inspect}#{" onto #{@onto.inspect}" if @onto}, but generated #{@actual.inspect}"
   end
 
   failure_message_when_negated do |_actual|
