@@ -1,6 +1,6 @@
 # frozen_string_literal: true
 
-describe Nanoc::CLI::Commands::ShowData, stdio: true do
+describe Nanoc::CLI::Commands::ShowData, :stdio do
   describe '#print_item_dependencies' do
     subject { runner.send(:print_item_dependencies, items, dependency_store) }
 
@@ -38,7 +38,7 @@ describe Nanoc::CLI::Commands::ShowData, stdio: true do
     end
 
     it 'prints a legend' do
-      expect { subject }.to output(%r{Item dependencies =+\n\nLegend:}).to_stdout
+      expect { subject }.to output(/Item dependencies =+\n\nLegend:/).to_stdout
     end
 
     context 'no dependencies' do
