@@ -1,6 +1,6 @@
 # frozen_string_literal: true
 
-describe Nanoc::CLI::CompileListeners::FileActionPrinter, stdio: true do
+describe Nanoc::CLI::CompileListeners::FileActionPrinter, :stdio do
   let(:listener) { described_class.new(reps:) }
   let(:reps) do
     Nanoc::Core::ItemRepRepo.new.tap do |reps|
@@ -20,7 +20,7 @@ describe Nanoc::CLI::CompileListeners::FileActionPrinter, stdio: true do
     allow(Process)
       .to receive(:clock_gettime)
       .with(Process::CLOCK_MONOTONIC, :nanosecond)
-      .and_return(original_timestamp + seconds * 1_000_000_000)
+      .and_return(original_timestamp + (seconds * 1_000_000_000))
   end
 
   after do
@@ -89,7 +89,7 @@ describe Nanoc::CLI::CompileListeners::FileActionPrinter, stdio: true do
         .not_to output(/skip/).to_stdout
     end
 
-    it 'prints nothing' do
+    it 'prints nothing after compilation_started' do
       Nanoc::Core::NotificationCenter.post(:compilation_started, rep)
       mock_time(1)
 
@@ -97,7 +97,7 @@ describe Nanoc::CLI::CompileListeners::FileActionPrinter, stdio: true do
         .not_to output(/identical/).to_stdout
     end
 
-    it 'prints nothing' do
+    it 'prints nothing after compilation_started and cached_content_used' do
       Nanoc::Core::NotificationCenter.post(:compilation_started, rep)
       Nanoc::Core::NotificationCenter.post(:cached_content_used, rep)
       mock_time(1)
@@ -115,7 +115,7 @@ describe Nanoc::CLI::CompileListeners::FileActionPrinter, stdio: true do
 
     it 'prints skipped (uncompiled) reps' do
       expect { listener.stop_safely }
-        .to output(/skip.*\/hi\.html/).to_stdout
+        .to output(%r{skip.*/hi\.html}).to_stdout
     end
 
     it 'prints “identical” if not cached' do
