@@ -1,6 +1,6 @@
 # frozen_string_literal: true
 
-describe Nanoc::CLI::CompileListeners::TimingRecorder, stdio: true do
+describe Nanoc::CLI::CompileListeners::TimingRecorder, :stdio do
   let(:listener) { described_class.new(reps:) }
   let(:reps) do
     Nanoc::Core::ItemRepRepo.new.tap do |reps|
@@ -25,7 +25,7 @@ describe Nanoc::CLI::CompileListeners::TimingRecorder, stdio: true do
     allow(Process)
       .to receive(:clock_gettime)
       .with(Process::CLOCK_MONOTONIC, :nanosecond)
-      .and_return(original_timestamp + seconds * 1_000_000_000)
+      .and_return(original_timestamp + (seconds * 1_000_000_000))
   end
 
   before do
@@ -39,13 +39,13 @@ describe Nanoc::CLI::CompileListeners::TimingRecorder, stdio: true do
 
   it 'prints filters table' do
     mock_time(0)
-    Nanoc::Core::NotificationCenter.post(:filtering_started, rep, :erb).sync
+    Nanoc::Core::NotificationCenter.post(:filtering_started, rep, :erb)
     mock_time(1)
-    Nanoc::Core::NotificationCenter.post(:filtering_ended, rep, :erb).sync
+    Nanoc::Core::NotificationCenter.post(:filtering_ended, rep, :erb)
     mock_time(100)
-    Nanoc::Core::NotificationCenter.post(:filtering_started, rep, :erb).sync
+    Nanoc::Core::NotificationCenter.post(:filtering_started, rep, :erb)
     mock_time(102)
-    Nanoc::Core::NotificationCenter.post(:filtering_ended, rep, :erb).sync
+    Nanoc::Core::NotificationCenter.post(:filtering_ended, rep, :erb)
 
     expect { listener.stop_safely }
       .to output(/^\s*erb │     2   1\.00s   1\.50s   1\.90s   1\.95s   2\.00s   3\.00s$/).to_stdout
@@ -53,9 +53,9 @@ describe Nanoc::CLI::CompileListeners::TimingRecorder, stdio: true do
 
   it 'records single from filtering_started to filtering_ended' do
     mock_time(0)
-    Nanoc::Core::NotificationCenter.post(:filtering_started, rep, :erb).sync
+    Nanoc::Core::NotificationCenter.post(:filtering_started, rep, :erb)
     mock_time(1)
-    Nanoc::Core::NotificationCenter.post(:filtering_ended, rep, :erb).sync
+    Nanoc::Core::NotificationCenter.post(:filtering_ended, rep, :erb)
 
     expect(listener.filters_summary.get(name: 'erb').min).to eq(1.00)
     expect(listener.filters_summary.get(name: 'erb').avg).to eq(1.00)
@@ -66,13 +66,13 @@ describe Nanoc::CLI::CompileListeners::TimingRecorder, stdio: true do
 
   it 'records multiple from filtering_started to filtering_ended' do
     mock_time(0)
-    Nanoc::Core::NotificationCenter.post(:filtering_started, rep, :erb).sync
+    Nanoc::Core::NotificationCenter.post(:filtering_started, rep, :erb)
     mock_time(1)
-    Nanoc::Core::NotificationCenter.post(:filtering_ended, rep, :erb).sync
+    Nanoc::Core::NotificationCenter.post(:filtering_ended, rep, :erb)
     mock_time(100)
-    Nanoc::Core::NotificationCenter.post(:filtering_started, rep, :erb).sync
+    Nanoc::Core::NotificationCenter.post(:filtering_started, rep, :erb)
     mock_time(102)
-    Nanoc::Core::NotificationCenter.post(:filtering_ended, rep, :erb).sync
+    Nanoc::Core::NotificationCenter.post(:filtering_ended, rep, :erb)
 
     expect(listener.filters_summary.get(name: 'erb').min).to eq(1.00)
     expect(listener.filters_summary.get(name: 'erb').avg).to eq(1.50)
@@ -83,13 +83,13 @@ describe Nanoc::CLI::CompileListeners::TimingRecorder, stdio: true do
 
   it 'records filters in nested filtering_started/filtering_ended' do
     mock_time(0)
-    Nanoc::Core::NotificationCenter.post(:filtering_started, rep, :outer).sync
+    Nanoc::Core::NotificationCenter.post(:filtering_started, rep, :outer)
     mock_time(1)
-    Nanoc::Core::NotificationCenter.post(:filtering_started, rep, :inner).sync
+    Nanoc::Core::NotificationCenter.post(:filtering_started, rep, :inner)
     mock_time(3)
-    Nanoc::Core::NotificationCenter.post(:filtering_ended, rep, :inner).sync
+    Nanoc::Core::NotificationCenter.post(:filtering_ended, rep, :inner)
     mock_time(6)
-    Nanoc::Core::NotificationCenter.post(:filtering_ended, rep, :outer).sync
+    Nanoc::Core::NotificationCenter.post(:filtering_ended, rep, :outer)
 
     expect(listener.filters_summary.get(name: 'inner').min).to eq(2.00)
     expect(listener.filters_summary.get(name: 'inner').avg).to eq(2.00)
@@ -104,50 +104,11 @@ describe Nanoc::CLI::CompileListeners::TimingRecorder, stdio: true do
     expect(listener.filters_summary.get(name: 'outer').count).to eq(1.00)
   end
 
-  it 'pauses outer stopwatch when suspended' do
-    mock_time(0)
-    Nanoc::Core::NotificationCenter.post(:compilation_started, rep).sync
-    Nanoc::Core::NotificationCenter.post(:filtering_started, rep, :outer).sync
-    mock_time(1)
-    Nanoc::Core::NotificationCenter.post(:filtering_started, rep, :inner).sync
-    mock_time(3)
-    Nanoc::Core::NotificationCenter.post(:compilation_suspended, rep, :__anything__).sync
-    mock_time(6)
-    Nanoc::Core::NotificationCenter.post(:compilation_started, rep).sync
-    mock_time(10)
-    Nanoc::Core::NotificationCenter.post(:filtering_ended, rep, :inner).sync
-    Nanoc::Core::NotificationCenter.post(:filtering_ended, rep, :outer).sync
-
-    expect(listener.filters_summary.get(name: 'outer').min).to eq(7.00)
-    expect(listener.filters_summary.get(name: 'outer').avg).to eq(7.00)
-    expect(listener.filters_summary.get(name: 'outer').max).to eq(7.00)
-    expect(listener.filters_summary.get(name: 'outer').sum).to eq(7.00)
-    expect(listener.filters_summary.get(name: 'outer').count).to eq(1.00)
-  end
-
-  it 'records single from filtering_started over compilation_{suspended,started} to filtering_ended' do
-    Nanoc::Core::NotificationCenter.post(:compilation_started, rep).sync
-    mock_time(0)
-    Nanoc::Core::NotificationCenter.post(:filtering_started, rep, :erb).sync
-    mock_time(1)
-    Nanoc::Core::NotificationCenter.post(:compilation_suspended, rep, :__anything__).sync
-    mock_time(3)
-    Nanoc::Core::NotificationCenter.post(:compilation_started, rep).sync
-    mock_time(7)
-    Nanoc::Core::NotificationCenter.post(:filtering_ended, rep, :erb).sync
-
-    expect(listener.filters_summary.get(name: 'erb').min).to eq(5.00)
-    expect(listener.filters_summary.get(name: 'erb').avg).to eq(5.00)
-    expect(listener.filters_summary.get(name: 'erb').max).to eq(5.00)
-    expect(listener.filters_summary.get(name: 'erb').sum).to eq(5.00)
-    expect(listener.filters_summary.get(name: 'erb').count).to eq(1.00)
-  end
-
   it 'records single phase start+stop' do
     mock_time(0)
-    Nanoc::Core::NotificationCenter.post(:phase_started, 'donkey', rep).sync
+    Nanoc::Core::NotificationCenter.post(:phase_started, 'donkey', rep)
     mock_time(1)
-    Nanoc::Core::NotificationCenter.post(:phase_ended, 'donkey', rep).sync
+    Nanoc::Core::NotificationCenter.post(:phase_ended, 'donkey', rep)
 
     expect(listener.phases_summary.get(name: 'donkey').min).to eq(1.00)
     expect(listener.phases_summary.get(name: 'donkey').avg).to eq(1.00)
@@ -158,13 +119,13 @@ describe Nanoc::CLI::CompileListeners::TimingRecorder, stdio: true do
 
   it 'records multiple phase start+stop' do
     mock_time(0)
-    Nanoc::Core::NotificationCenter.post(:phase_started, 'donkey', rep).sync
+    Nanoc::Core::NotificationCenter.post(:phase_started, 'donkey', rep)
     mock_time(1)
-    Nanoc::Core::NotificationCenter.post(:phase_ended, 'donkey', rep).sync
+    Nanoc::Core::NotificationCenter.post(:phase_ended, 'donkey', rep)
     mock_time(100)
-    Nanoc::Core::NotificationCenter.post(:phase_started, 'donkey', rep).sync
+    Nanoc::Core::NotificationCenter.post(:phase_started, 'donkey', rep)
     mock_time(102)
-    Nanoc::Core::NotificationCenter.post(:phase_ended, 'donkey', rep).sync
+    Nanoc::Core::NotificationCenter.post(:phase_ended, 'donkey', rep)
 
     expect(listener.phases_summary.get(name: 'donkey').min).to eq(1.00)
     expect(listener.phases_summary.get(name: 'donkey').avg).to eq(1.50)
@@ -175,13 +136,13 @@ describe Nanoc::CLI::CompileListeners::TimingRecorder, stdio: true do
 
   it 'records single phase start+yield+resume+stop' do
     mock_time(0)
-    Nanoc::Core::NotificationCenter.post(:phase_started, 'donkey', rep).sync
+    Nanoc::Core::NotificationCenter.post(:phase_started, 'donkey', rep)
     mock_time(1)
-    Nanoc::Core::NotificationCenter.post(:phase_yielded, 'donkey', rep).sync
+    Nanoc::Core::NotificationCenter.post(:phase_yielded, 'donkey', rep)
     mock_time(100)
-    Nanoc::Core::NotificationCenter.post(:phase_resumed, 'donkey', rep).sync
+    Nanoc::Core::NotificationCenter.post(:phase_resumed, 'donkey', rep)
     mock_time(102)
-    Nanoc::Core::NotificationCenter.post(:phase_ended, 'donkey', rep).sync
+    Nanoc::Core::NotificationCenter.post(:phase_ended, 'donkey', rep)
 
     expect(listener.phases_summary.get(name: 'donkey').min).to eq(3.00)
     expect(listener.phases_summary.get(name: 'donkey').avg).to eq(3.00)
@@ -192,15 +153,15 @@ describe Nanoc::CLI::CompileListeners::TimingRecorder, stdio: true do
 
   it 'records single phase start+yield+abort+start+stop' do
     mock_time(0)
-    Nanoc::Core::NotificationCenter.post(:phase_started, 'donkey', rep).sync
+    Nanoc::Core::NotificationCenter.post(:phase_started, 'donkey', rep)
     mock_time(1)
-    Nanoc::Core::NotificationCenter.post(:phase_yielded, 'donkey', rep).sync
+    Nanoc::Core::NotificationCenter.post(:phase_yielded, 'donkey', rep)
     mock_time(100)
-    Nanoc::Core::NotificationCenter.post(:phase_aborted, 'donkey', rep).sync
+    Nanoc::Core::NotificationCenter.post(:phase_aborted, 'donkey', rep)
     mock_time(200)
-    Nanoc::Core::NotificationCenter.post(:phase_started, 'donkey', rep).sync
+    Nanoc::Core::NotificationCenter.post(:phase_started, 'donkey', rep)
     mock_time(203)
-    Nanoc::Core::NotificationCenter.post(:phase_ended, 'donkey', rep).sync
+    Nanoc::Core::NotificationCenter.post(:phase_ended, 'donkey', rep)
 
     expect(listener.phases_summary.get(name: 'donkey').min).to eq(1.00)
     expect(listener.phases_summary.get(name: 'donkey').avg).to eq(2.00)
@@ -210,28 +171,28 @@ describe Nanoc::CLI::CompileListeners::TimingRecorder, stdio: true do
   end
 
   it 'records stage duration' do
-    Nanoc::Core::NotificationCenter.post(:stage_ran, 1.23, 'donkey_stage').sync
+    Nanoc::Core::NotificationCenter.post(:stage_ran, 1.23, 'donkey_stage')
 
     expect(listener.stages_summary.get(name: 'donkey_stage').sum).to eq(1.23)
     expect(listener.stages_summary.get(name: 'donkey_stage').count).to eq(1)
   end
 
   it 'prints stage durations' do
-    Nanoc::Core::NotificationCenter.post(:stage_ran, 1.23, 'donkey_stage').sync
+    Nanoc::Core::NotificationCenter.post(:stage_ran, 1.23, 'donkey_stage')
 
     expect { listener.stop_safely }
       .to output(/^\s*donkey_stage │ 1\.23s$/).to_stdout
   end
 
   it 'prints out outdatedness rule durations' do
-    Nanoc::Core::NotificationCenter.post(:outdatedness_rule_ran, 1.0, Nanoc::Core::OutdatednessRules::CodeSnippetsModified).sync
+    Nanoc::Core::NotificationCenter.post(:outdatedness_rule_ran, 1.0, Nanoc::Core::OutdatednessRules::CodeSnippetsModified)
 
     expect { listener.stop_safely }
       .to output(/^\s*CodeSnippetsModified │     1   1\.00s   1\.00s   1\.00s   1\.00s   1\.00s   1\.00s$/).to_stdout
   end
 
   it 'records single outdatedness rule duration' do
-    Nanoc::Core::NotificationCenter.post(:outdatedness_rule_ran, 1.0, Nanoc::Core::OutdatednessRules::CodeSnippetsModified).sync
+    Nanoc::Core::NotificationCenter.post(:outdatedness_rule_ran, 1.0, Nanoc::Core::OutdatednessRules::CodeSnippetsModified)
 
     expect(listener.outdatedness_rules_summary.get(name: 'CodeSnippetsModified').min).to eq(1.00)
     expect(listener.outdatedness_rules_summary.get(name: 'CodeSnippetsModified').avg).to eq(1.00)
@@ -241,8 +202,8 @@ describe Nanoc::CLI::CompileListeners::TimingRecorder, stdio: true do
   end
 
   it 'records multiple outdatedness rule duration' do
-    Nanoc::Core::NotificationCenter.post(:outdatedness_rule_ran, 1.0, Nanoc::Core::OutdatednessRules::CodeSnippetsModified).sync
-    Nanoc::Core::NotificationCenter.post(:outdatedness_rule_ran, 3.0, Nanoc::Core::OutdatednessRules::CodeSnippetsModified).sync
+    Nanoc::Core::NotificationCenter.post(:outdatedness_rule_ran, 1.0, Nanoc::Core::OutdatednessRules::CodeSnippetsModified)
+    Nanoc::Core::NotificationCenter.post(:outdatedness_rule_ran, 3.0, Nanoc::Core::OutdatednessRules::CodeSnippetsModified)
 
     expect(listener.outdatedness_rules_summary.get(name: 'CodeSnippetsModified').min).to eq(1.00)
     expect(listener.outdatedness_rules_summary.get(name: 'CodeSnippetsModified').avg).to eq(2.00)
@@ -252,14 +213,14 @@ describe Nanoc::CLI::CompileListeners::TimingRecorder, stdio: true do
   end
 
   it 'prints load store durations' do
-    Nanoc::Core::NotificationCenter.post(:store_loaded, 1.23, Nanoc::Core::ChecksumStore).sync
+    Nanoc::Core::NotificationCenter.post(:store_loaded, 1.23, Nanoc::Core::ChecksumStore)
 
     expect { listener.stop_safely }
       .to output(/^\s*Nanoc::Core::ChecksumStore │ 1\.23s$/).to_stdout
   end
 
   it 'prints store store durations' do
-    Nanoc::Core::NotificationCenter.post(:store_stored, 2.34, Nanoc::Core::ChecksumStore).sync
+    Nanoc::Core::NotificationCenter.post(:store_stored, 2.34, Nanoc::Core::ChecksumStore)
 
     expect { listener.stop_safely }
       .to output(/^\s*Nanoc::Core::ChecksumStore │ 2\.34s$/).to_stdout
