@@ -8,7 +8,7 @@ describe Nanoc::CLI::StackTraceWriter do
   let(:io) { StringIO.new }
 
   describe '#write' do
-    subject { writer.write(exception, verbose: verbose) }
+    subject { writer.write(exception, verbose:) }
 
     let(:exception) do
       backtrace_generator = lambda do |af|
@@ -49,7 +49,7 @@ describe Nanoc::CLI::StackTraceWriter do
         expect { subject }
           .to change(io, :string)
           .from('')
-          .to(match(%r{^  11\. }))
+          .to(match(/^  11\. /))
       end
 
       it 'does not contain a see-more explanation' do
