@@ -14,13 +14,13 @@ Class.new(Nanoc::Core::DataSource) do
 
   def items
     Dir['content/*'].map do |filename|
-      Nanoc::Core::Item.new(File.read(filename), {}, filename.sub(/^content\//, '/'))
+      Nanoc::Core::Item.new(File.read(filename), {}, filename.sub(%r{^content/}, '/'))
     end
   end
 
   def layouts
     Dir['layouts/*'].map do |filename|
-      Nanoc::Core::Layout.new(File.read(filename), {}, filename.sub(/^layouts\//, '/'))
+      Nanoc::Core::Layout.new(File.read(filename), {}, filename.sub(%r{^layouts/}, '/'))
     end
   end
 end
@@ -38,7 +38,7 @@ Class.new(Nanoc::Core::ActionProvider) do
   end
 
   def preprocess(site)
-    item = site.items['/hello.*']
+    item = site.items.object_matching_glob('/hello.*')
 
     if item
       item.content = Nanoc::Core::TextualContent.new('Better hello!')
@@ -53,7 +53,6 @@ Class.new(Nanoc::Core::ActionProvider) do
 
   def action_sequence_for(rep)
     Nanoc::Core::ActionSequence.new(
-      rep,
       actions: [
         Nanoc::Core::ProcessingActions::Snapshot.new([:last], [rep.item.identifier.to_s]),
       ],
