@@ -2,7 +2,6 @@
 
 # Ruby stdlib
 require 'base64'
-require 'fiber'
 require 'find'
 require 'singleton'
 require 'tmpdir'
@@ -10,7 +9,6 @@ require 'yaml'
 require 'zlib'
 
 # External gems
-require 'clonefile'
 require 'concurrent-ruby'
 require 'json_schema'
 require 'ddmetrics'
@@ -21,6 +19,13 @@ require 'slow_enumerator_tools'
 require 'tty-platform'
 require 'zeitwerk'
 
+# External gems (optional)
+begin
+  require 'clonefile'
+rescue LoadError
+  # ignore
+end
+
 module Nanoc
   module Core
     # Similar to `nil` except that it can only be compared against using
@@ -42,7 +47,7 @@ module Nanoc
     # @api private
     def self.version_information
       "Nanoc #{Nanoc::Core::VERSION} © 2007–… Denis Defreyne.\n" \
-      "Running #{RUBY_ENGINE} #{RUBY_VERSION} (#{RUBY_RELEASE_DATE}) on #{RUBY_PLATFORM} with RubyGems #{Gem::VERSION}.\n"
+        "Running #{RUBY_ENGINE} #{RUBY_VERSION} (#{RUBY_RELEASE_DATE}) on #{RUBY_PLATFORM} with RubyGems #{Gem::VERSION}.\n"
     end
 
     # @return [Boolean] True if the current platform is Windows, false otherwise.
@@ -68,6 +73,7 @@ end
 loader = Zeitwerk::Loader.new
 loader.inflector = inflector_class.new
 loader.push_dir(__dir__ + '/..')
+loader.push_dir(__dir__ + '/core/views', namespace: Nanoc::Core)
 loader.ignore(__dir__ + '/../nanoc-core.rb')
 loader.ignore(__dir__ + '/core/core_ext')
 loader.setup
