@@ -33,7 +33,12 @@ module Nanoc
             end
           end
 
-          selector = Nanoc::Core::ItemRepSelector.new(outdated_reps)
+          selector = Nanoc::Core::ItemRepSelector.new(
+            outdated_reps:,
+            reps: @reps,
+            dependency_store: @dependency_store,
+          )
+
           run_phase_stack do |phase_stack|
             selector.each do |rep|
               handle_errors_while(rep) do
@@ -83,12 +88,12 @@ module Nanoc
 
           cache_phase = Nanoc::Core::CompilationPhases::Cache.new(
             compiled_content_cache: @compiled_content_cache,
-            compiled_content_store: @compilation_context.compiled_content_store,
+            compiled_content_repo: @compilation_context.compiled_content_repo,
             wrapped: recalculate_phase,
           )
 
           write_phase = Nanoc::Core::CompilationPhases::Write.new(
-            compiled_content_store: @compilation_context.compiled_content_store,
+            compiled_content_repo: @compilation_context.compiled_content_repo,
             wrapped: cache_phase,
           )
 
