@@ -14,15 +14,17 @@ describe Nanoc::Core::Executor do
 
   let(:compilation_context) do
     Nanoc::Core::CompilationContext.new(
-      action_provider: action_provider,
-      reps: reps,
-      site: site,
-      compiled_content_cache: compiled_content_cache,
-      compiled_content_store: compiled_content_store,
+      action_provider:,
+      reps:,
+      site:,
+      compiled_content_cache:,
+      compiled_content_repo:,
+      outdatedness_store: Nanoc::Core::OutdatednessStore.new(config:),
     )
   end
 
   let(:item) { Nanoc::Core::Item.new(content, {}, '/index.md') }
+  let(:root_item) { Nanoc::Core::Item.new('root', {}, '/root.md') }
   let(:rep) { Nanoc::Core::ItemRep.new(item, :donkey) }
   let(:content) { Nanoc::Core::TextualContent.new('Donkey Power').tap(&:freeze) }
 
@@ -42,7 +44,7 @@ describe Nanoc::Core::Executor do
 
   let(:site) do
     Nanoc::Core::Site.new(
-      config: config,
+      config:,
       code_snippets: [],
       data_source: Nanoc::Core::InMemoryDataSource.new(items, layouts),
     )
@@ -61,12 +63,13 @@ describe Nanoc::Core::Executor do
   let(:config) { Nanoc::Core::Configuration.new(hash: config_hash, dir: Dir.getwd).with_defaults }
 
   let(:compiled_content_cache) do
-    Nanoc::Core::CompiledContentCache.new(config: config)
+    Nanoc::Core::CompiledContentCache.new(config:)
   end
 
-  let(:compiled_content_store) { Nanoc::Core::CompiledContentStore.new }
+  let(:compiled_content_repo) { Nanoc::Core::CompiledContentRepo.new }
 
-  let(:dependency_tracker) { Nanoc::Core::DependencyTracker.new(double(:dependency_store)) }
+  let(:dependency_tracker) { Nanoc::Core::DependencyTracker.new(dependency_store, root: root_item) }
+  let(:dependency_store) { Nanoc::Core::DependencyStore.new(items, layouts, config) }
 
   describe '#filter' do
     let(:assigns) { {} }
@@ -82,27 +85,27 @@ describe Nanoc::Core::Executor do
         expect(Nanoc::Core::NotificationCenter)
           .to receive(:post).with(:filtering_ended, rep, :simple_erb_uy2wbp6dcf4hlc4gbluauh07zuz2wvei)
 
-        compiled_content_store.set_current(rep, content)
+        compiled_content_repo.set_current(rep, content)
       end
 
       it 'does not set :pre in repo' do
-        expect(compiled_content_store.get(rep, :pre)).to be_nil
-        expect { subject }.not_to change { compiled_content_store.get(rep, :pre) }
+        expect(compiled_content_repo.get(rep, :pre)).to be_nil
+        expect { subject }.not_to change { compiled_content_repo.get(rep, :pre) }
       end
 
       it 'does not set :post in repo' do
-        expect(compiled_content_store.get(rep, :post)).to be_nil
-        expect { subject }.not_to change { compiled_content_store.get(rep, :post) }
+        expect(compiled_content_repo.get(rep, :post)).to be_nil
+        expect { subject }.not_to change { compiled_content_repo.get(rep, :post) }
       end
 
       it 'does not set :last in repo' do
-        expect(compiled_content_store.get(rep, :last)).to be_nil
-        expect { subject }.not_to change { compiled_content_store.get(rep, :last) }
+        expect(compiled_content_repo.get(rep, :last)).to be_nil
+        expect { subject }.not_to change { compiled_content_repo.get(rep, :last) }
       end
 
       it 'updates current content in repo' do
         expect { subject }
-          .to change { compiled_content_store.get_current(rep).string }
+          .to change { compiled_content_repo.get_current(rep).string }
           .from('<%= "Donkey" %> Power')
           .to('Donkey Power')
       end
@@ -110,7 +113,7 @@ describe Nanoc::Core::Executor do
       it 'returns frozen data' do
         executor.filter(:simple_erb_uy2wbp6dcf4hlc4gbluauh07zuz2wvei)
 
-        expect(compiled_content_store.get_current(rep)).to be_frozen
+        expect(compiled_content_repo.get_current(rep)).to be_frozen
       end
     end
 
@@ -137,35 +140,35 @@ describe Nanoc::Core::Executor do
 
         expect(Nanoc::Core::Filter).to receive(:named).with(:whatever) { filter_class }
 
-        compiled_content_store.set_current(rep, content)
+        compiled_content_repo.set_current(rep, content)
       end
 
       it 'does not set :pre in repo' do
-        expect(compiled_content_store.get(rep, :pre)).to be_nil
-        expect { subject }.not_to change { compiled_content_store.get(rep, :pre) }
+        expect(compiled_content_repo.get(rep, :pre)).to be_nil
+        expect { subject }.not_to change { compiled_content_repo.get(rep, :pre) }
       end
 
       it 'does not set :post in repo' do
-        expect(compiled_content_store.get(rep, :post)).to be_nil
-        expect { subject }.not_to change { compiled_content_store.get(rep, :post) }
+        expect(compiled_content_repo.get(rep, :post)).to be_nil
+        expect { subject }.not_to change { compiled_content_repo.get(rep, :post) }
       end
 
       it 'does not set :last in repo' do
-        expect(compiled_content_store.get(rep, :last)).to be_nil
-        expect { subject }.not_to change { compiled_content_store.get(rep, :last) }
+        expect(compiled_content_repo.get(rep, :last)).to be_nil
+        expect { subject }.not_to change { compiled_content_repo.get(rep, :last) }
       end
 
       it 'updates current content in repo' do
         expect { subject }
-          .to change { File.read(compiled_content_store.get_current(rep).filename) }
+          .to change { File.read(compiled_content_repo.get_current(rep).filename) }
           .from('Foo Data')
-          .to(/\ACompiled data for (C:)?\/.*\/foo.dat\z/)
+          .to(%r{\ACompiled data for (C:)?/.*/foo.dat\z})
       end
 
       it 'returns frozen data' do
         executor.filter(:whatever)
 
-        expect(compiled_content_store.get_current(rep)).to be_frozen
+        expect(compiled_content_repo.get_current(rep)).to be_frozen
       end
     end
 
@@ -192,29 +195,29 @@ describe Nanoc::Core::Executor do
 
         expect(Nanoc::Core::Filter).to receive(:named).with(:whatever) { filter_class }
 
-        compiled_content_store.set_current(rep, content)
+        compiled_content_repo.set_current(rep, content)
       end
 
       it 'does not set :pre in repo' do
-        expect(compiled_content_store.get(rep, :pre)).to be_nil
-        expect { subject }.not_to change { compiled_content_store.get(rep, :pre) }
+        expect(compiled_content_repo.get(rep, :pre)).to be_nil
+        expect { subject }.not_to change { compiled_content_repo.get(rep, :pre) }
       end
 
       it 'does not set :post in repo' do
-        expect(compiled_content_store.get(rep, :post)).to be_nil
-        expect { subject }.not_to change { compiled_content_store.get(rep, :post) }
+        expect(compiled_content_repo.get(rep, :post)).to be_nil
+        expect { subject }.not_to change { compiled_content_repo.get(rep, :post) }
       end
 
       it 'does not set :last in repo' do
-        expect(compiled_content_store.get(rep, :last)).to be_nil
-        expect { subject }.not_to change { compiled_content_store.get(rep, :last) }
+        expect(compiled_content_repo.get(rep, :last)).to be_nil
+        expect { subject }.not_to change { compiled_content_repo.get(rep, :last) }
       end
 
       it 'updates current content repo' do
         expect { subject }
-          .to change { compiled_content_store.get_current(rep) }
+          .to change { compiled_content_repo.get_current(rep) }
           .from(some_binary_content('Foo Data'))
-          .to(some_textual_content(/\ACompiled data for (C:)?\/.*\/foo.dat\z/))
+          .to(some_textual_content(%r{\ACompiled data for (C:)?/.*/foo.dat\z}))
       end
     end
 
@@ -237,27 +240,27 @@ describe Nanoc::Core::Executor do
 
         expect(Nanoc::Core::Filter).to receive(:named).with(:whatever) { filter_class }
 
-        compiled_content_store.set_current(rep, content)
+        compiled_content_repo.set_current(rep, content)
       end
 
       it 'does not set :pre in repo' do
-        expect(compiled_content_store.get(rep, :pre)).to be_nil
-        expect { subject }.not_to change { compiled_content_store.get(rep, :pre) }
+        expect(compiled_content_repo.get(rep, :pre)).to be_nil
+        expect { subject }.not_to change { compiled_content_repo.get(rep, :pre) }
       end
 
       it 'does not set :post in repo' do
-        expect(compiled_content_store.get(rep, :post)).to be_nil
-        expect { subject }.not_to change { compiled_content_store.get(rep, :post) }
+        expect(compiled_content_repo.get(rep, :post)).to be_nil
+        expect { subject }.not_to change { compiled_content_repo.get(rep, :post) }
       end
 
       it 'does not set :last in repo' do
-        expect(compiled_content_store.get(rep, :last)).to be_nil
-        expect { subject }.not_to change { compiled_content_store.get(rep, :last) }
+        expect(compiled_content_repo.get(rep, :last)).to be_nil
+        expect { subject }.not_to change { compiled_content_repo.get(rep, :last) }
       end
 
       it 'updates current content in repo' do
         expect { subject }
-          .to change { compiled_content_store.get_current(rep) }
+          .to change { compiled_content_repo.get_current(rep) }
           .from(some_textual_content('<%= "Donkey" %> Power'))
           .to(some_binary_content('Binary <%= "Donkey" %> Power'))
       end
@@ -280,7 +283,7 @@ describe Nanoc::Core::Executor do
 
         expect(Nanoc::Core::Filter).to receive(:named).with(:whatever) { filter_class }
 
-        compiled_content_store.set_current(rep, content)
+        compiled_content_repo.set_current(rep, content)
       end
 
       it 'raises' do
@@ -293,7 +296,7 @@ describe Nanoc::Core::Executor do
       let(:content) { Nanoc::Core::BinaryContent.new(File.expand_path('foo.md')) }
 
       before do
-        compiled_content_store.set_current(rep, content)
+        compiled_content_repo.set_current(rep, content)
       end
 
       it 'raises' do
@@ -320,7 +323,7 @@ describe Nanoc::Core::Executor do
           def run(_filename, _params = {}); end
         end
 
-        compiled_content_store.set_current(rep, content)
+        compiled_content_repo.set_current(rep, content)
 
         expect(Nanoc::Core::Filter).to receive(:named).with(:whatever) { filter_class }
       end
@@ -333,7 +336,7 @@ describe Nanoc::Core::Executor do
 
     context 'content is frozen' do
       before do
-        compiled_content_store.set_current(rep, item.content)
+        compiled_content_repo.set_current(rep, item.content)
       end
 
       let(:item) do
@@ -382,7 +385,7 @@ describe Nanoc::Core::Executor do
     before do
       rep.snapshot_defs = [Nanoc::Core::SnapshotDef.new(:pre, binary: false)]
 
-      compiled_content_store.set_current(rep, content)
+      compiled_content_repo.set_current(rep, content)
 
       allow(action_provider).to receive(:action_sequence_for).with(layout).and_return(action_sequence)
     end
@@ -397,32 +400,33 @@ describe Nanoc::Core::Executor do
           .with(layout, raw_content: false, attributes: [:bug], compiled_content: false, path: false)
         allow(dependency_tracker).to receive(:exit)
         subject
-        expect(compiled_content_store.get_current(rep).string).to eq('head Gum Emperor foot')
+        expect(compiled_content_repo.get_current(rep).string).to eq('head Gum Emperor foot')
       end
     end
 
     context 'normal flow' do
       it 'updates :last in repo' do
         expect { subject }
-          .to change { compiled_content_store.get_current(rep) }
+          .to change { compiled_content_repo.get_current(rep) }
           .from(some_textual_content('Donkey Power'))
           .to(some_textual_content('head Donkey Power foot'))
       end
 
       it 'sets frozen content' do
         subject
-        expect(compiled_content_store.get_current(rep)).to be_frozen
-        expect(compiled_content_store.get(rep, :pre)).to be_frozen
+        expect(compiled_content_repo.get_current(rep)).to be_frozen
+        expect(compiled_content_repo.get(rep, :pre)).to be_frozen
       end
 
       it 'does not create pre snapshot' do
         # a #layout is followed by a #snapshot(:pre, …)
-        expect(compiled_content_store.get(rep, :pre)).to be_nil
+        expect(compiled_content_repo.get(rep, :pre)).to be_nil
         subject
-        expect(compiled_content_store.get(rep, :pre)).to be_nil
+        expect(compiled_content_repo.get(rep, :pre)).to be_nil
       end
 
       it 'sends notifications' do
+        expect(Nanoc::Core::NotificationCenter).to receive(:post).with(:dependency_created, root_item, layout).ordered
         expect(Nanoc::Core::NotificationCenter).to receive(:post).with(:filtering_started, rep, :simple_erb_uy2wbp6dcf4hlc4gbluauh07zuz2wvei).ordered
         expect(Nanoc::Core::NotificationCenter).to receive(:post).with(:filtering_ended, rep, :simple_erb_uy2wbp6dcf4hlc4gbluauh07zuz2wvei).ordered
 
@@ -441,13 +445,13 @@ describe Nanoc::Core::Executor do
         end
 
         it 'does not set :last in repo' do
-          expect(compiled_content_store.get(rep, :last)).to be_nil
-          expect { subject }.not_to change { compiled_content_store.get(rep, :last) }
+          expect(compiled_content_repo.get(rep, :last)).to be_nil
+          expect { subject }.not_to change { compiled_content_repo.get(rep, :last) }
         end
 
         it 'updates current content in repo' do
           expect { subject }
-            .to change { compiled_content_store.get_current(rep) }
+            .to change { compiled_content_repo.get_current(rep) }
             .from(some_textual_content('Donkey Power'))
             .to(some_textual_content('head Donkey Power foot'))
         end
@@ -457,13 +461,13 @@ describe Nanoc::Core::Executor do
         let(:layout_content) { 'head <%= @layout.identifier %> foot' }
 
         it 'does not set :last in repo' do
-          expect(compiled_content_store.get(rep, :last)).to be_nil
-          expect { subject }.not_to change { compiled_content_store.get(rep, :last) }
+          expect(compiled_content_repo.get(rep, :last)).to be_nil
+          expect { subject }.not_to change { compiled_content_repo.get(rep, :last) }
         end
 
         it 'updates current content in repo' do
           expect { subject }
-            .to change { compiled_content_store.get_current(rep) }
+            .to change { compiled_content_repo.get_current(rep) }
             .from(some_textual_content('Donkey Power'))
             .to(some_textual_content('head /default.erb foot'))
         end
@@ -522,7 +526,7 @@ describe Nanoc::Core::Executor do
     subject { executor.snapshot(:something) }
 
     before do
-      compiled_content_store.set_current(rep, content)
+      compiled_content_repo.set_current(rep, content)
 
       File.write('donkey.dat', 'binary donkey')
     end
@@ -532,7 +536,7 @@ describe Nanoc::Core::Executor do
 
       it 'creates snapshots in repo' do
         expect { subject }
-          .to change { compiled_content_store.get(rep, :something) }
+          .to change { compiled_content_repo.get(rep, :something) }
           .from(nil)
           .to(some_binary_content('binary donkey'))
       end
@@ -543,7 +547,7 @@ describe Nanoc::Core::Executor do
 
       it 'creates snapshots in repo' do
         expect { subject }
-          .to change { compiled_content_store.get(rep, :something) }
+          .to change { compiled_content_repo.get(rep, :something) }
           .from(nil)
           .to(some_textual_content('Donkey Power'))
       end
