@@ -9,7 +9,7 @@ shared_examples 'an item rep view' do
       items:,
       dependency_tracker:,
       compilation_context:,
-      compiled_content_store:,
+      compiled_content_repo:,
     )
   end
 
@@ -19,7 +19,8 @@ shared_examples 'an item rep view' do
       reps:,
       site:,
       compiled_content_cache:,
-      compiled_content_store:,
+      compiled_content_repo:,
+      outdatedness_store: Nanoc::Core::OutdatednessStore.new(config:),
     )
   end
 
@@ -27,7 +28,7 @@ shared_examples 'an item rep view' do
   let(:layouts) { Nanoc::Core::LayoutCollection.new(config) }
   let(:reps) { Nanoc::Core::ItemRepRepo.new }
 
-  let(:compiled_content_store) { Nanoc::Core::CompiledContentStore.new }
+  let(:compiled_content_repo) { Nanoc::Core::CompiledContentRepo.new }
   let(:compiled_content_cache) { Nanoc::Core::CompiledContentCache.new(config:) }
 
   let(:action_provider) do
@@ -40,7 +41,7 @@ shared_examples 'an item rep view' do
     end.new
   end
 
-  let(:dependency_tracker) { Nanoc::Core::DependencyTracker.new(dependency_store) }
+  let(:dependency_tracker) { Nanoc::Core::DependencyTracker.new(dependency_store, root: base_item) }
   let(:dependency_store) { Nanoc::Core::DependencyStore.new(empty_items, empty_layouts, config) }
   let(:base_item) { Nanoc::Core::Item.new('base', {}, '/base.md') }
 
@@ -57,10 +58,6 @@ shared_examples 'an item rep view' do
     )
   end
 
-  before do
-    dependency_tracker.enter(base_item)
-  end
-
   describe '#frozen?' do
     subject { view.frozen? }
 
@@ -123,39 +120,6 @@ shared_examples 'an item rep view' do
       end
     end
 
-    context 'comparing with item rep with same identifier' do
-      let(:other_item) { double(:other_item, identifier: '/foo') }
-      let(:other) { described_class.new(double(:other_item_rep, item: other_item, name: :jacques), view_context) }
-
-      it 'is ==' do
-        expect(view).to eq(other)
-      end
-
-      it 'is eql?' do
-        expect(view).not_to eql(other)
-      end
-    end
-
-    context 'comparing with item rep with different identifier' do
-      let(:other_item) { double(:other_item, identifier: '/bar') }
-      let(:other) { described_class.new(double(:other_item_rep, item: other_item, name: :jacques), view_context) }
-
-      it 'is not equal' do
-        expect(view).not_to eq(other)
-        expect(view).not_to eql(other)
-      end
-    end
-
-    context 'comparing with item rep with different name' do
-      let(:other_item) { double(:other_item, identifier: '/foo') }
-      let(:other) { described_class.new(double(:other_item_rep, item: other_item, name: :marvin), view_context) }
-
-      it 'is not equal' do
-        expect(view).not_to eq(other)
-        expect(view).not_to eql(other)
-      end
-    end
-
     context 'comparing with something that is not an item rep' do
       let(:other_item) { double(:other_item, identifier: '/foo') }
       let(:other) { :donkey }
@@ -198,7 +162,7 @@ shared_examples 'an item rep view' do
     let(:snapshot_name) { raise 'override me' }
 
     before do
-      compiled_content_store.set(rep, :last, Nanoc::Core::TextualContent.new('Hallo'))
+      compiled_content_repo.set(rep, :last, Nanoc::Core::TextualContent.new('Hallo'))
     end
 
     context 'snapshot exists' do
