@@ -9,28 +9,33 @@ shared_examples 'a mutable document view' do
       items: Nanoc::Core::ItemCollection.new(config),
       dependency_tracker:,
       compilation_context:,
-      compiled_content_store:,
+      compiled_content_repo:,
     )
   end
 
-  let(:dependency_tracker) { Nanoc::Core::DependencyTracker.new(double(:dependency_store)) }
+  let(:dependency_tracker) { Nanoc::Core::DependencyTracker.new(dependency_store, root: root_item) }
+  let(:dependency_store) { Nanoc::Core::DependencyStore.new(items, layouts, config) }
 
   let(:config) { Nanoc::Core::Configuration.new(dir: Dir.getwd).with_defaults }
   let(:items) { Nanoc::Core::ItemCollection.new(config) }
   let(:layouts) { Nanoc::Core::LayoutCollection.new(config) }
   let(:reps) { Nanoc::Core::ItemRepRepo.new }
 
+  let(:root_item) { Nanoc::Core::Item.new('root', {}, '/root.md') }
+
   let(:compilation_context) do
     Nanoc::Core::CompilationContext.new(
       action_provider:,
       reps:,
       site:,
       compiled_content_cache:,
-      compiled_content_store:,
+      compiled_content_repo:,
+
+      outdatedness_store: Nanoc::Core::OutdatednessStore.new(config:),
     )
   end
 
-  let(:compiled_content_store) { Nanoc::Core::CompiledContentStore.new }
+  let(:compiled_content_repo) { Nanoc::Core::CompiledContentRepo.new }
   let(:compiled_content_cache) { Nanoc::Core::CompiledContentCache.new(config:) }
 
   let(:site) do
