@@ -152,6 +152,7 @@ module Nanoc::DataSources
       is_binary = content_filename && !@site_config[:text_extensions].include?(File.extname(content_filename)[1..])
 
       if is_binary && klass == Nanoc::Core::Item
+        # NOTE: TOML support is explicitly not added here, in case there are existing sites with `.toml` files.
         meta = (meta_filename && Nanoc::Core::YamlLoader.load_file(meta_filename)) || {}
 
         ProtoDocument.new(is_binary: true, filename: content_filename, attributes: meta)
@@ -301,7 +302,7 @@ module Nanoc::DataSources
 
       by_basename =
         all_files_in(dir_name)
-        .reject   { |fn| fn =~ /(~|\.orig|\.rej|\.bak)$/ }
+        .grep_v(/(~|\.orig|\.rej|\.bak)$/)
         .group_by { |fn| basename_of(fn) }
 
       all = {}
@@ -363,10 +364,10 @@ module Nanoc::DataSources
       end
 
       regex =
-        if /(^|\/)index(\.[^\/]+)?$/.match?(filename)
-          allow_periods_in_identifiers? ? /\/?(index)?(\.[^\/.]+)?$/ : /\/?index(\.[^\/]+)?$/
+        if %r{(^|/)index(\.[^/]+)?$}.match?(filename)
+          allow_periods_in_identifiers? ? %r{/?(index)?(\.[^/.]+)?$} : %r{/?index(\.[^/]+)?$}
         else
-          allow_periods_in_identifiers? ? /\.[^\/.]+$/ : /\.[^\/]+$/
+          allow_periods_in_identifiers? ? %r{\.[^/.]+$} : %r{\.[^/]+$}
         end
       Nanoc::Core::Identifier.new(filename.sub(regex, ''), type: :legacy)
     end
@@ -392,9 +393,9 @@ module Nanoc::DataSources
     # @return [Regex]
     def extension_regex
       if allow_periods_in_identifiers?
-        /(\.[^\/.]+$)/
+        %r{(\.[^/.]+$)}
       else
-        /(\.[^\/]+$)/
+        %r{(\.[^/]+$)}
       end
     end
 
