@@ -20,7 +20,7 @@ module Nanoc::Helpers
         content_string = capture(&)
 
         # Get existing contents and prep for store
-        compiled_content_store = @item._context.compiled_content_store
+        compiled_content_repo = @item._context.compiled_content_repo
         rep = @item.reps[:default]._unwrap
         capture_name = :"__capture_#{@name}"
         old_content_string =
@@ -28,10 +28,10 @@ module Nanoc::Helpers
           when :overwrite
             ''
           when :append
-            c = compiled_content_store.get(rep, capture_name)
+            c = compiled_content_repo.get(rep, capture_name)
             c ? c.string : ''
           when :error
-            contents = compiled_content_store.get(rep, capture_name)
+            contents = compiled_content_repo.get(rep, capture_name)
             if contents && contents.string != content_string
               # FIXME: get proper exception
               raise "a capture named #{@name.inspect} for #{@item.identifier} already exists"
@@ -40,12 +40,12 @@ module Nanoc::Helpers
             end
           else
             raise ArgumentError, 'expected :existing_behavior param to #content_for to be one of ' \
-              ":overwrite, :append, or :error, but #{existing_behavior.inspect} was given"
+                                 ":overwrite, :append, or :error, but #{existing_behavior.inspect} was given"
           end
 
         # Store
         new_content = Nanoc::Core::TextualContent.new(old_content_string + content_string)
-        compiled_content_store.set(rep, capture_name, new_content)
+        compiled_content_repo.set(rep, capture_name, new_content)
       end
     end
 
@@ -59,22 +59,28 @@ module Nanoc::Helpers
       end
 
       def run
-        rep = @requested_item.reps[:default]._unwrap
+        rep_view = @requested_item.reps[:default]
+        rep = rep_view._unwrap
 
         # Create dependency
         if @item.nil? || @requested_item != @item._unwrap
           dependency_tracker = @config._context.dependency_tracker
           dependency_tracker.bounce(@requested_item._unwrap, compiled_content: true)
 
+          unless rep.compiled?
+            rep_view._try_load_from_cache
+          end
+
+          # If the item rep still isn’t compiled by now, then it can’t be loaded
+          # from the cache and needs to compiled as usual.
           unless rep.compiled?
             # FIXME: is :last appropriate?
-            Fiber.yield(Nanoc::Core::Errors::UnmetDependency.new(rep, :last))
-            return run
+            raise Nanoc::Core::Errors::UnmetDependency.new(rep, :last)
           end
         end
 
-        compiled_content_store = @config._context.compiled_content_store
-        content = compiled_content_store.get(rep, :"__capture_#{@name}")
+        compiled_content_repo = @config._context.compiled_content_repo
+        content = compiled_content_repo.get(rep, :"__capture_#{@name}")
         content&.string
       end
     end
@@ -113,7 +119,7 @@ module Nanoc::Helpers
             args[1]
           else
             raise ArgumentError, 'expected 1 or 2 argument (the name ' \
-              "of the capture, and optionally params) but got #{args.size} instead"
+                                 "of the capture, and optionally params) but got #{args.size} instead"
           end
 
         SetContent.new(name, params, @item).run(&)
@@ -128,7 +134,7 @@ module Nanoc::Helpers
             args[1]
           else
             raise ArgumentError, 'expected 2 or 3 arguments (the name ' \
-              "of the capture, optionally params, and the content) but got #{args.size} instead"
+                                 "of the capture, optionally params, and the content) but got #{args.size} instead"
           end
 
         _erbout = +'' # rubocop:disable Lint/UnderscorePrefixedVariableName
@@ -136,7 +142,7 @@ module Nanoc::Helpers
       else # Get content
         if args.size != 2
           raise ArgumentError, 'expected 2 arguments (the item ' \
-            "and the name of the capture) but got #{args.size} instead"
+                               "and the name of the capture) but got #{args.size} instead"
         end
         requested_item = args[0]
         name = args[1]
