@@ -1,6 +1,6 @@
 # frozen_string_literal: true
 
-describe Nanoc::Helpers::Rendering, helper: true do
+describe Nanoc::Helpers::Rendering, :helper do
   describe '#render' do
     subject { helper.instance_eval { render('/partial.erb') } }
 
@@ -33,11 +33,8 @@ describe Nanoc::Helpers::Rendering, helper: true do
           it { is_expected.to eql('blah') }
 
           it 'tracks proper dependencies' do
-            expect(ctx.dependency_tracker).to receive(:enter)
-              .with(layout, raw_content: true, attributes: false, compiled_content: false, path: false)
-              .ordered
-
-            subject
+            expect { subject }
+              .to create_dependency_on(layout_view)
           end
         end
 
