@@ -1,6 +1,6 @@
 # frozen_string_literal: true
 
-describe 'GH-1248', site: true, stdio: true do
+describe 'GH-1248', :site, :stdio do
   before do
     File.write('content/stuff.html', 'hi')
 
@@ -11,14 +11,12 @@ describe 'GH-1248', site: true, stdio: true do
 
       passthrough '/**/*'
     EOS
-  end
 
-  before do
     Nanoc::CLI.run(%w[compile])
   end
 
   example do
     expect { Nanoc::CLI.run(%w[compile --verbose]) }
-      .not_to output(/identical .* ootpoot\/stuff.html/).to_stdout
+      .not_to output(%r{identical .* ootpoot/stuff.html}).to_stdout
   end
 end
