@@ -1,6 +1,6 @@
 # frozen_string_literal: true
 
-describe 'GH-1342', site: true, stdio: true do
+describe 'GH-1342', :site, :stdio do
   before do
     File.write('Rules', <<~EOS)
       preprocess do
@@ -18,7 +18,7 @@ describe 'GH-1342', site: true, stdio: true do
     EOS
   end
 
-  example do
+  example do # rubocop:disable RSpec/NoExpectationExample
     Nanoc::CLI.run([])
     Nanoc::CLI.run([])
   end
