@@ -1,6 +1,6 @@
 # frozen_string_literal: true
 
-describe 'GH-767', site: true do
+describe 'GH-767', :site do
   before do
     File.write('content/donkey.md', 'Compiled content donkey!')
 
