@@ -1,26 +1,24 @@
 # frozen_string_literal: true
 
-describe 'GH-776', site: true do
+describe 'GH-776', :site do
   before do
     File.write('content/donkey.md', 'Donkey!')
 
-    File.write('Rules', <<EOS)
-  compile '/donkey.*' do
-    filter :erb
-    snapshot :secret, path: '/donkey-secret.html'
-    write '/donkey.html'
-  end
+    File.write('Rules', <<~EOS)
+      compile '/donkey.*' do
+        filter :erb
+        snapshot :secret, path: '/donkey-secret.html'
+        write '/donkey.html'
+      end
 
-  layout '/foo.*', :erb
-EOS
+      layout '/foo.*', :erb
+    EOS
+
+    Nanoc::Core::Compiler.compile(site)
   end
 
   let(:site) { Nanoc::Core::SiteLoader.new.new_from_cwd }
 
-  before do
-    Nanoc::Core::Compiler.compile(site)
-  end
-
   context 'without pruning' do
     it 'writes two files' do
       expect(File.read('output/donkey.html')).to eql('Donkey!')
