@@ -1,6 +1,6 @@
 # frozen_string_literal: true
 
-describe 'GH-804', site: true, stdio: true do
+describe 'GH-804', :site, :stdio do
   before do
     File.write('content/item.md', 'Stuff!')
     File.write('Rules', <<EOS)
@@ -21,7 +21,7 @@ EOS
   it 'does not crash' do
     expect { Nanoc::CLI.run(%w[check donkey]) }.to(
       raise_error(Nanoc::Core::TrivialError, 'One or more checks failed').and(
-        output(/Issues found!\n  \(global\):\n    \[ (\e\[31m)?ERROR(\e\[0m)? \] donkey - Not enough donkeys\n  \/catlady.md:\n    \[ (\e\[31m)?ERROR(\e\[0m)? \] donkey - Too many cats\n/).to_stdout,
+        output(%r{Issues found!\n  \(global\):\n    \[ (\e\[31m)?ERROR(\e\[0m)? \] donkey - Not enough donkeys\n  /catlady.md:\n    \[ (\e\[31m)?ERROR(\e\[0m)? \] donkey - Too many cats\n}).to_stdout,
       ),
     )
   end
