@@ -1,6 +1,6 @@
 # frozen_string_literal: true
 
-describe 'GH-970 (show-data)', site: true, stdio: true do
+describe 'GH-970 (show-data)', :site, :stdio do
   before do
     File.write('content/foo.md', 'foo')
     File.write('content/bar.md', '<%= @items["/foo.*"].compiled_content %>')
@@ -21,10 +21,10 @@ describe 'GH-970 (show-data)', site: true, stdio: true do
 
   it 'shows default rep outdatedness' do
     expect { Nanoc::CLI.run(%w[show-data --no-color]) }.to(
-      output(/^item \/foo\.md, rep default:\n  is not outdated/).to_stdout,
+      output(%r{^item /foo\.md, rep default:\n  is not outdated}).to_stdout,
     )
     expect { Nanoc::CLI.run(%w[show-data --no-color]) }.to(
-      output(/^item \/bar\.md, rep default:\n  is not outdated/).to_stdout,
+      output(%r{^item /bar\.md, rep default:\n  is not outdated}).to_stdout,
     )
   end
 
@@ -32,10 +32,10 @@ describe 'GH-970 (show-data)', site: true, stdio: true do
     File.write('content/bar.md', 'JUST BAR!')
 
     expect { Nanoc::CLI.run(%w[show-data --no-color]) }.to(
-      output(/^item \/foo\.md, rep default:\n  is not outdated/).to_stdout,
+      output(%r{^item /foo\.md, rep default:\n  is not outdated}).to_stdout,
     )
     expect { Nanoc::CLI.run(%w[show-data --no-color]) }.to(
-      output(/^item \/bar\.md, rep default:\n  is outdated:/).to_stdout,
+      output(%r{^item /bar\.md, rep default:\n  is outdated:}).to_stdout,
     )
   end
 
@@ -43,10 +43,10 @@ describe 'GH-970 (show-data)', site: true, stdio: true do
     File.write('content/foo.md', 'FOO!')
 
     expect { Nanoc::CLI.run(%w[show-data --no-color]) }.to(
-      output(/^item \/foo\.md, rep default:\n  is outdated:/).to_stdout,
+      output(%r{^item /foo\.md, rep default:\n  is outdated:}).to_stdout,
     )
     expect { Nanoc::CLI.run(%w[show-data --no-color]) }.to(
-      output(/^item \/bar\.md, rep default:\n  is outdated:/).to_stdout,
+      output(%r{^item /bar\.md, rep default:\n  is outdated:}).to_stdout,
     )
   end
 end
