@@ -58,7 +58,7 @@ class Nanoc::DataSources::FilesystemTest < Nanoc::TestCase
     actual_out = data_source.send(:load_objects, 'foo', klass).sort_by { |i| i.stuff[0].string }
 
     # Check
-    (0..expected_out.size - 1).each do |i|
+    (0..(expected_out.size - 1)).each do |i|
       assert_equal expected_out[i].stuff[0], actual_out[i].stuff[0].string, 'content must match'
       assert_equal expected_out[i].stuff[2], actual_out[i].stuff[2], 'identifier must match'
       ['num', :filename, :extension, :mtime].each do |key|
@@ -380,12 +380,19 @@ class Nanoc::DataSources::FilesystemTest < Nanoc::TestCase
     actual_out = data_source.send(:load_objects, 'foo', klass).sort_by { |i| i.stuff[2] }
 
     # Check
-    (0..expected_out.size - 1).each do |i|
+    (0..(expected_out.size - 1)).each do |i|
       assert_equal expected_out[i].stuff[0], actual_out[i].stuff[0].string, 'content must match'
       assert_equal expected_out[i].stuff[2], actual_out[i].stuff[2], 'identifier must match'
 
       ['num', :content_filename, :meta_filename, :extension, :mtime].each do |key|
-        assert_equal expected_out[i].stuff[1][key], actual_out[i].stuff[1][key], "attribute key #{key} must match"
+        expected = expected_out[i].stuff[1][key]
+        actual = actual_out[i].stuff[1][key]
+
+        if expected
+          assert_equal expected, actual, "attribute key #{key} must match"
+        else
+          assert_nil actual, "attribute key #{key} must match"
+        end
       end
     end
   end
@@ -463,12 +470,19 @@ class Nanoc::DataSources::FilesystemTest < Nanoc::TestCase
     actual_out = data_source.send(:load_objects, 'foo', klass).sort_by { |i| i.stuff[2] }
 
     # Check
-    (0..expected_out.size - 1).each do |i|
+    (0..(expected_out.size - 1)).each do |i|
       assert_equal expected_out[i].stuff[0], actual_out[i].stuff[0].string, 'content must match'
       assert_equal expected_out[i].stuff[2], actual_out[i].stuff[2], 'identifier must match'
 
       ['num', :content_filename, :meta_filename, :extension, :mtime].each do |key|
-        assert_equal expected_out[i].stuff[1][key], actual_out[i].stuff[1][key], "attribute key #{key} must match"
+        expected = expected_out[i].stuff[1][key]
+        actual = actual_out[i].stuff[1][key]
+
+        if expected
+          assert_equal expected, actual, "attribute key #{key} must match"
+        else
+          assert_nil actual, "attribute key #{key} must match"
+        end
       end
     end
   end
