@@ -11,7 +11,7 @@ class Nanoc::Filters::RDiscountTest < Nanoc::TestCase
       # Run filter
       result = filter.setup_and_run('> Quote')
 
-      assert_match(/<blockquote>\s*<p>Quote<\/p>\s*<\/blockquote>/, result)
+      assert_match(%r{<blockquote>\s*<p>Quote</p>\s*</blockquote>}, result)
     end
   end
 
