@@ -92,12 +92,10 @@ class Nanoc::Filters::XSLTest < Nanoc::TestCase
     items = Nanoc::Core::ItemCollection.new(config)
     layouts = Nanoc::Core::LayoutCollection.new(config)
 
+    @root_item = Nanoc::Core::Item.new('base', {}, '/base.md')
+
     @dependency_store = Nanoc::Core::DependencyStore.new(items, layouts, config)
-    @dependency_tracker = Nanoc::Core::DependencyTracker.new(@dependency_store)
-
-    @base_item = Nanoc::Core::Item.new('base', {}, '/base.md')
-
-    @dependency_tracker.enter(@base_item)
+    @dependency_tracker = Nanoc::Core::DependencyTracker.new(@dependency_store, root: @root_item)
   end
 
   def new_view_context
@@ -115,7 +113,7 @@ class Nanoc::Filters::XSLTest < Nanoc::TestCase
       )
 
     compiled_content_cache = Nanoc::Core::CompiledContentCache.new(config:)
-    compiled_content_store = Nanoc::Core::CompiledContentStore.new
+    compiled_content_repo = Nanoc::Core::CompiledContentRepo.new
 
     action_provider =
       Class.new(Nanoc::Core::ActionProvider) do
@@ -132,7 +130,8 @@ class Nanoc::Filters::XSLTest < Nanoc::TestCase
         reps:,
         site:,
         compiled_content_cache:,
-        compiled_content_store:,
+        compiled_content_repo:,
+        outdatedness_store: Nanoc::Core::OutdatednessStore.new(config:),
       )
 
     Nanoc::Core::ViewContextForCompilation.new(
@@ -140,7 +139,7 @@ class Nanoc::Filters::XSLTest < Nanoc::TestCase
       items: Nanoc::Core::ItemCollection.new(config),
       dependency_tracker: @dependency_tracker,
       compilation_context:,
-      compiled_content_store: Nanoc::Core::CompiledContentStore.new,
+      compiled_content_repo: Nanoc::Core::CompiledContentRepo.new,
     )
   end
 
@@ -166,7 +165,7 @@ class Nanoc::Filters::XSLTest < Nanoc::TestCase
       assert_match SAMPLE_XML_OUT, result
 
       # Verify dependencies
-      dep = @dependency_store.dependencies_causing_outdatedness_of(@base_item)[0]
+      dep = @dependency_store.dependencies_causing_outdatedness_of(@root_item)[0]
 
       refute_nil dep
     end
@@ -194,7 +193,7 @@ class Nanoc::Filters::XSLTest < Nanoc::TestCase
       assert_match SAMPLE_XML_OUT_WITH_PARAMS, result
 
       # Verify dependencies
-      dep = @dependency_store.dependencies_causing_outdatedness_of(@base_item)[0]
+      dep = @dependency_store.dependencies_causing_outdatedness_of(@root_item)[0]
 
       refute_nil dep
     end
@@ -222,7 +221,7 @@ class Nanoc::Filters::XSLTest < Nanoc::TestCase
       assert_match SAMPLE_XML_OUT_WITH_OMIT_XML_DECL, result
 
       # Verify dependencies
-      dep = @dependency_store.dependencies_causing_outdatedness_of(@base_item)[0]
+      dep = @dependency_store.dependencies_causing_outdatedness_of(@root_item)[0]
 
       refute_nil dep
     end
