@@ -44,11 +44,13 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
         data_source: Nanoc::Core::InMemoryDataSource.new(items, layouts),
       )
 
+    root_item = Nanoc::Core::Item.new('base', {}, '/base.md')
+
     dep_store = Nanoc::Core::DependencyStore.new(items, layouts, config)
-    dependency_tracker = Nanoc::Core::DependencyTracker.new(dep_store)
+    dependency_tracker = Nanoc::Core::DependencyTracker.new(dep_store, root: root_item)
 
     compiled_content_cache = Nanoc::Core::CompiledContentCache.new(config:)
-    compiled_content_store = Nanoc::Core::CompiledContentStore.new
+    compiled_content_repo = Nanoc::Core::CompiledContentRepo.new
 
     action_provider =
       Class.new(Nanoc::Core::ActionProvider) do
@@ -65,7 +67,8 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
         reps:,
         site:,
         compiled_content_cache:,
-        compiled_content_store:,
+        compiled_content_repo:,
+        outdatedness_store: Nanoc::Core::OutdatednessStore.new(config:),
       )
 
     @view_context = Nanoc::Core::ViewContextForCompilation.new(
@@ -73,7 +76,7 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
       items:,
       dependency_tracker:,
       compilation_context:,
-      compiled_content_store: Nanoc::Core::CompiledContentStore.new,
+      compiled_content_repo: Nanoc::Core::CompiledContentRepo.new,
     )
   end
 
@@ -617,6 +620,28 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
     assert_match 'foobar!</title>', result
   end
 
+  def test_atom_feed_with_id_proc_param
+    # Mock article
+    @items = [mock_article]
+
+    # Mock site
+    config = Nanoc::Core::Configuration.new(hash: { base_url: 'http://example.com' }, dir: Dir.getwd)
+    @config = Nanoc::Core::ConfigView.new(config, @view_context)
+
+    # Create feed item
+    @item = mock
+    @item.stubs(:identifier).returns('/abc.md')
+    @item.stubs(:[]).with(:title).returns('My Blog Or Something')
+    @item.stubs(:[]).with(:author_name).returns('J. Doe')
+    @item.stubs(:[]).with(:author_uri).returns('http://example.com/~jdoe')
+    @item.stubs(:[]).with(:[]).with(:feed_url).returns('http://example.com/feed')
+
+    # Check
+    result = atom_feed id_proc: ->(_a) { "example.com/xyzzy,2000-01-01,#{@item.identifier}" }
+
+    assert_match '<id>example.com/xyzzy,2000-01-01,/abc.md</id>', result
+  end
+
   def test_atom_feed_with_icon_param
     # Mock article
     @items = [mock_article]
