@@ -8,11 +8,13 @@ class Nanoc::Helpers::XMLSitemapTest < Nanoc::TestCase
   def setup
     super
 
+    root_item = Nanoc::Core::Item.new('base', {}, '/base.md')
+
     config = Nanoc::Core::Configuration.new(dir: Dir.getwd).with_defaults
     items = Nanoc::Core::ItemCollection.new(config)
     layouts = Nanoc::Core::LayoutCollection.new(config)
     dep_store = Nanoc::Core::DependencyStore.new(items, layouts, config)
-    dependency_tracker = Nanoc::Core::DependencyTracker.new(dep_store)
+    dependency_tracker = Nanoc::Core::DependencyTracker.new(dep_store, root: root_item)
     @reps = Nanoc::Core::ItemRepRepo.new
 
     site =
@@ -23,7 +25,7 @@ class Nanoc::Helpers::XMLSitemapTest < Nanoc::TestCase
       )
 
     compiled_content_cache = Nanoc::Core::CompiledContentCache.new(config:)
-    compiled_content_store = Nanoc::Core::CompiledContentStore.new
+    compiled_content_repo = Nanoc::Core::CompiledContentRepo.new
 
     action_provider =
       Class.new(Nanoc::Core::ActionProvider) do
@@ -40,7 +42,8 @@ class Nanoc::Helpers::XMLSitemapTest < Nanoc::TestCase
         reps: @reps,
         site:,
         compiled_content_cache:,
-        compiled_content_store:,
+        compiled_content_repo:,
+        outdatedness_store: Nanoc::Core::OutdatednessStore.new(config:),
       )
 
     @view_context = Nanoc::Core::ViewContextForCompilation.new(
@@ -48,7 +51,7 @@ class Nanoc::Helpers::XMLSitemapTest < Nanoc::TestCase
       items: Nanoc::Core::ItemCollection.new(config),
       dependency_tracker:,
       compilation_context:,
-      compiled_content_store: Nanoc::Core::CompiledContentStore.new,
+      compiled_content_repo: Nanoc::Core::CompiledContentRepo.new,
     )
 
     @items = nil
