@@ -93,8 +93,8 @@ class Nanoc::RuleDSL::CompilerDSLTest < Nanoc::TestCase
       File.write(
         'Rules',
         "include_rules 'more_rules'\n\n" \
-          "route '/**/*' do ; nil ; end\n\n" \
-          "compile '/**/*' do ; end\n",
+        "route '/**/*' do ; nil ; end\n\n" \
+        "compile '/**/*' do ; end\n",
       )
 
       # Create items
@@ -283,7 +283,7 @@ class Nanoc::RuleDSL::CompilerDSLTest < Nanoc::TestCase
     refute pattern.match?('/foo/aaaa/')
     refute pattern.match?('/foo/a/a/a/a')
     # rubocop:enable Minitest/RefuteMatch
-    # rubocop:enable Minitest/AssertMatch Minitest/RefuteMatch
+    # rubocop:enable Minitest/AssertMatch
   end
 
   def test_create_pattern_with_regex
@@ -398,8 +398,8 @@ class Nanoc::RuleDSL::CompilerDSLTest < Nanoc::TestCase
 
     # rubocop:disable Minitest/AssertMatch
     # rubocop:disable Minitest/RefuteMatch
-    assert('/foo/bar/' =~ actual)
-    refute('/foo/' =~ actual)
+    assert_operator('/foo/bar/', :=~, actual)
+    refute_operator('/foo/', :=~, actual)
     # rubocop:enable Minitest/RefuteMatch
     # rubocop:enable Minitest/AssertMatch
   end
@@ -415,9 +415,9 @@ class Nanoc::RuleDSL::CompilerDSLTest < Nanoc::TestCase
 
     # rubocop:disable Minitest/AssertMatch
     # rubocop:disable Minitest/RefuteMatch
-    assert('/favicon.ico' =~ actual)
-    assert('/favicon.ico/' =~ actual)
-    refute('/faviconxico' =~ actual)
+    assert_operator('/favicon.ico', :=~, actual)
+    assert_operator('/favicon.ico/', :=~, actual)
+    refute_operator('/faviconxico', :=~, actual)
     # rubocop:enable Minitest/RefuteMatch
     # rubocop:enable Minitest/AssertMatch
   end
